@@ -1,7 +1,7 @@
 library(testthat)
 library(SUMO)  # Load your package
 test_that("plot_weights runs without error", {
-  output_obj <- OmixCraftHD(
+  output_obj <- simulate_twoOmicsData(
      vector_features = c(4000, 3000),
      n_samples = 100,
      n_factors = 2,
